!
!= ѿΰ
!
! Authors::   Yasuhiro MORIKAWA, Eizi TOYODA
! Version::   $Id: gtvarputline.f90,v 1.4 2006/10/09 10:35:42 morikawa Exp $
! Tag Name::  $Name: gt4f90io-20061009 $
! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
! License::   See COPYRIGHT[link:../../COPYRIGHT]
!
! ʲΥ֥롼󡢴ؿ gtdata_generic  gtdata_generic#Put_Line
! Ȥ󶡤ޤ

subroutine GTVarPutLine(var, err)
  !
  !== ѿΰ
  !
  ! ѿ *var* ƤϤޤ
  !
  ! Get Ƚ񼰤Ĥ WRITE ʸ򤢤碌褦ʵǽǡ
  ! ѿ *var* Ƥɸ (Τˤ * Ǽ̤) 
  ! ˰ޤ
  !
  ! 顼硢å
  ! ƥץ϶λޤ*err* ͿƤˤ
  ! ΰ .true. ֤ꡢץϽλޤ
  !
  use gtdata_types, only: GT_VARIABLE
  use dc_error, only: ErrorCode, StoreError, GT_ENOMEM
  use dc_string, only: toChar, Printf
  use gtdata_generic, only: Get, Inquire
  use dc_trace, only: beginsub, endsub, DbgMessage
  implicit none
  type(GT_VARIABLE), intent(inout):: var
  logical, intent(out), optional:: err
  real, allocatable:: rvalue(:)
  integer:: siz, stat, i
  logical:: myerr
continue
  call beginsub('gtvarputline', '%d', i=(/var%mapid/))
  call Inquire(var, size=siz)
  call DbgMessage('size = %d', i=(/siz/))
  stat = 0
  allocate(rvalue(siz), stat=stat)
  if (stat /= 0) then
    stat = GT_ENOMEM
    goto 950
  endif
  call Get(var, rvalue, size(rvalue), err=myerr)
  if (myerr) then
    stat = ErrorCode()
    goto 950
  endif
  do, i = 1, size(rvalue)
    call Printf(fmt='%r', r=(/rvalue(i)/))
  end do
  deallocate(rvalue, stat=stat)
  if (stat /= 0) stat = GT_ENOMEM
  !
950 continue
  call StoreError(stat, "GTVarPutLine", err)
  call endsub('gtvarputline', '%d stat=%d', i=(/var%mapid, stat/))
end subroutine GTVarPutLine
